#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_3 import density as density_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .vaporization_model import vaporization_model as vaporization_model_cls
from .thermolysis_model import thermolysis_model as thermolysis_model_cls
from .latent_heat_1 import latent_heat as latent_heat_cls
from .volatile_fraction import volatile_fraction as volatile_fraction_cls
from .heat_of_pyrolysis import heat_of_pyrolysis as heat_of_pyrolysis_cls
from .specific_heat_3 import specific_heat as specific_heat_cls
from .binary_diffusivity_1 import binary_diffusivity as binary_diffusivity_cls
from .diffusivity_reference_pressure import diffusivity_reference_pressure as diffusivity_reference_pressure_cls
from .averaging_coefficient_t import averaging_coefficient_t as averaging_coefficient_t_cls
from .averaging_coefficient_y import averaging_coefficient_y as averaging_coefficient_y_cls
from .vapor_pressure import vapor_pressure as vapor_pressure_cls
from .molecular_weight_1 import molecular_weight as molecular_weight_cls
from .vaporization_temperature import vaporization_temperature as vaporization_temperature_cls
from .boiling_point import boiling_point as boiling_point_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .scattering_factor_1 import scattering_factor as scattering_factor_cls
from .emissivity_1 import emissivity as emissivity_cls
from .viscosity_2 import viscosity as viscosity_cls
from .dpm_surften_1 import dpm_surften as dpm_surften_cls
from .electric_conductivity_1 import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity_1 import dual_electric_conductivity as dual_electric_conductivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .charge_density import charge_density as charge_density_cls
from .formation_entropy import formation_entropy as formation_entropy_cls
from .formation_enthalpy import formation_enthalpy as formation_enthalpy_cls
from .reference_temperature_1 import reference_temperature as reference_temperature_cls
class droplet_particle_child(Group):
    """
    'child_object_type' of droplet_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'thermal_conductivity',
         'vaporization_model', 'thermolysis_model', 'latent_heat',
         'volatile_fraction', 'heat_of_pyrolysis', 'specific_heat',
         'binary_diffusivity', 'diffusivity_reference_pressure',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'vapor_pressure', 'molecular_weight', 'vaporization_temperature',
         'boiling_point', 'thermophoretic_co', 'scattering_factor',
         'emissivity', 'viscosity', 'dpm_surften', 'electric_conductivity',
         'dual_electric_conductivity', 'magnetic_permeability',
         'charge_density', 'formation_entropy', 'formation_enthalpy',
         'reference_temperature']

    name: name_cls = name_cls
    """
    name child of droplet_particle_child.
    """
    chemical_formula: chemical_formula_cls = chemical_formula_cls
    """
    chemical_formula child of droplet_particle_child.
    """
    density: density_cls = density_cls
    """
    density child of droplet_particle_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of droplet_particle_child.
    """
    vaporization_model: vaporization_model_cls = vaporization_model_cls
    """
    vaporization_model child of droplet_particle_child.
    """
    thermolysis_model: thermolysis_model_cls = thermolysis_model_cls
    """
    thermolysis_model child of droplet_particle_child.
    """
    latent_heat: latent_heat_cls = latent_heat_cls
    """
    latent_heat child of droplet_particle_child.
    """
    volatile_fraction: volatile_fraction_cls = volatile_fraction_cls
    """
    volatile_fraction child of droplet_particle_child.
    """
    heat_of_pyrolysis: heat_of_pyrolysis_cls = heat_of_pyrolysis_cls
    """
    heat_of_pyrolysis child of droplet_particle_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of droplet_particle_child.
    """
    binary_diffusivity: binary_diffusivity_cls = binary_diffusivity_cls
    """
    binary_diffusivity child of droplet_particle_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure_cls = diffusivity_reference_pressure_cls
    """
    diffusivity_reference_pressure child of droplet_particle_child.
    """
    averaging_coefficient_t: averaging_coefficient_t_cls = averaging_coefficient_t_cls
    """
    averaging_coefficient_t child of droplet_particle_child.
    """
    averaging_coefficient_y: averaging_coefficient_y_cls = averaging_coefficient_y_cls
    """
    averaging_coefficient_y child of droplet_particle_child.
    """
    vapor_pressure: vapor_pressure_cls = vapor_pressure_cls
    """
    vapor_pressure child of droplet_particle_child.
    """
    molecular_weight: molecular_weight_cls = molecular_weight_cls
    """
    molecular_weight child of droplet_particle_child.
    """
    vaporization_temperature: vaporization_temperature_cls = vaporization_temperature_cls
    """
    vaporization_temperature child of droplet_particle_child.
    """
    boiling_point: boiling_point_cls = boiling_point_cls
    """
    boiling_point child of droplet_particle_child.
    """
    thermophoretic_co: thermophoretic_co_cls = thermophoretic_co_cls
    """
    thermophoretic_co child of droplet_particle_child.
    """
    scattering_factor: scattering_factor_cls = scattering_factor_cls
    """
    scattering_factor child of droplet_particle_child.
    """
    emissivity: emissivity_cls = emissivity_cls
    """
    emissivity child of droplet_particle_child.
    """
    viscosity: viscosity_cls = viscosity_cls
    """
    viscosity child of droplet_particle_child.
    """
    dpm_surften: dpm_surften_cls = dpm_surften_cls
    """
    dpm_surften child of droplet_particle_child.
    """
    electric_conductivity: electric_conductivity_cls = electric_conductivity_cls
    """
    electric_conductivity child of droplet_particle_child.
    """
    dual_electric_conductivity: dual_electric_conductivity_cls = dual_electric_conductivity_cls
    """
    dual_electric_conductivity child of droplet_particle_child.
    """
    magnetic_permeability: magnetic_permeability_cls = magnetic_permeability_cls
    """
    magnetic_permeability child of droplet_particle_child.
    """
    charge_density: charge_density_cls = charge_density_cls
    """
    charge_density child of droplet_particle_child.
    """
    formation_entropy: formation_entropy_cls = formation_entropy_cls
    """
    formation_entropy child of droplet_particle_child.
    """
    formation_enthalpy: formation_enthalpy_cls = formation_enthalpy_cls
    """
    formation_enthalpy child of droplet_particle_child.
    """
    reference_temperature: reference_temperature_cls = reference_temperature_cls
    """
    reference_temperature child of droplet_particle_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class use_quad_face_centroid(Boolean):
    """
    Enable/disable using of quad face centroids when creating subtets.
    """

    fluent_name = "use-quad-face-centroid?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .flux import flux as flux_cls
from .gradient import gradient as gradient_cls
class anisotropic_solid_heat_transfer(Group):
    """
    'anisotropic_solid_heat_transfer' child.
    """

    fluent_name = "anisotropic-solid-heat-transfer"

    child_names = \
        ['flux', 'gradient']

    flux: flux_cls = flux_cls
    """
    flux child of anisotropic_solid_heat_transfer.
    """
    gradient: gradient_cls = gradient_cls
    """
    gradient child of anisotropic_solid_heat_transfer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .limiter_enabled import limiter_enabled as limiter_enabled_cls
from .report_leidenfrost_temperature import report_leidenfrost_temperature as report_leidenfrost_temperature_cls
from .offset_above_film_boiling_temperature import offset_above_film_boiling_temperature as offset_above_film_boiling_temperature_cls
class wall_film_temperature_limiter(Group):
    """
    'wall_film_temperature_limiter' child.
    """

    fluent_name = "wall-film-temperature-limiter"

    child_names = \
        ['limiter_enabled', 'report_leidenfrost_temperature',
         'offset_above_film_boiling_temperature']

    limiter_enabled: limiter_enabled_cls = limiter_enabled_cls
    """
    limiter_enabled child of wall_film_temperature_limiter.
    """
    report_leidenfrost_temperature: report_leidenfrost_temperature_cls = report_leidenfrost_temperature_cls
    """
    report_leidenfrost_temperature child of wall_film_temperature_limiter.
    """
    offset_above_film_boiling_temperature: offset_above_film_boiling_temperature_cls = offset_above_film_boiling_temperature_cls
    """
    offset_above_film_boiling_temperature child of wall_film_temperature_limiter.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .surface_names_2 import surface_names as surface_names_cls
from .geometry_names import geometry_names as geometry_names_cls
from .cust_vec_func import cust_vec_func as cust_vec_func_cls
from .report_of import report_of as report_of_cls
from .current_domain import current_domain as current_domain_cls
from .write_to_file_1 import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
class vertex_avg(Command):
    """
    Print average of scalar at vertices of the surfaces.
    
    Parameters
    ----------
        surface_names : typing.List[str]
            Select surface.
        geometry_names : typing.List[str]
            Select UTL Geometry.
        cust_vec_func : str
            'cust_vec_func' child.
        report_of : str
            Specify Field.
        current_domain : str
            'current_domain' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
    
    """

    fluent_name = "vertex-avg"

    argument_names = \
        ['surface_names', 'geometry_names', 'cust_vec_func', 'report_of',
         'current_domain', 'write_to_file', 'file_name', 'append_data']

    surface_names: surface_names_cls = surface_names_cls
    """
    surface_names argument of vertex_avg.
    """
    geometry_names: geometry_names_cls = geometry_names_cls
    """
    geometry_names argument of vertex_avg.
    """
    cust_vec_func: cust_vec_func_cls = cust_vec_func_cls
    """
    cust_vec_func argument of vertex_avg.
    """
    report_of: report_of_cls = report_of_cls
    """
    report_of argument of vertex_avg.
    """
    current_domain: current_domain_cls = current_domain_cls
    """
    current_domain argument of vertex_avg.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file argument of vertex_avg.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of vertex_avg.
    """
    append_data: append_data_cls = append_data_cls
    """
    append_data argument of vertex_avg.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class report_definitions:
    fluent_name = ...
    child_names = ...
    mesh = ...
    surface = ...
    volume = ...
    force = ...
    lift = ...
    drag = ...
    moment = ...
    flux = ...
    injection = ...
    user_defined = ...
    aeromechanics = ...
    icing = ...
    expression = ...
    single_val_expression = ...
    custom = ...
    command_names = ...

    def compute(self, report_defs: List[str]):
        """
        'compute' command.
        
        Parameters
        ----------
            report_defs : typing.List[str]
                'report_defs' child.
        
        """

    def copy(self, copy_from: str, copy_to: str):
        """
        'copy' command.
        
        Parameters
        ----------
            copy_from : str
                'copy_from' child.
            copy_to : str
                'copy_to' child.
        
        """

    def list(self, ):
        """
        'list' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .solution_controls import solution_controls as solution_controls_cls
from .tolerance_1 import tolerance as tolerance_cls
from .convert_to_mapped_interface import convert_to_mapped_interface as convert_to_mapped_interface_cls
class mapped_interface_options(Group):
    """
    Enter the mapped-interface-options menu.
    """

    fluent_name = "mapped-interface-options"

    command_names = \
        ['solution_controls', 'tolerance', 'convert_to_mapped_interface']

    solution_controls: solution_controls_cls = solution_controls_cls
    """
    solution_controls command of mapped_interface_options.
    """
    tolerance: tolerance_cls = tolerance_cls
    """
    tolerance command of mapped_interface_options.
    """
    convert_to_mapped_interface: convert_to_mapped_interface_cls = convert_to_mapped_interface_cls
    """
    convert_to_mapped_interface command of mapped_interface_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class turbulent_diffusion(Boolean):
    """
    New turbulent diffusion treatment is applicable to N-phase flow when one of the phases 
    participating in cavitation is selected as a primary phase.
    """

    fluent_name = "turbulent-diffusion?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_5 import density as density_cls
from .specific_heat_4 import specific_heat as specific_heat_cls
from .species_4 import species as species_cls
from .vp_equilib import vp_equilib as vp_equilib_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .viscosity_2 import viscosity as viscosity_cls
from .dpm_surften import dpm_surften as dpm_surften_cls
from .emissivity_2 import emissivity as emissivity_cls
from .scattering_factor_2 import scattering_factor as scattering_factor_cls
from .vaporization_model import vaporization_model as vaporization_model_cls
from .averaging_coefficient_t import averaging_coefficient_t as averaging_coefficient_t_cls
from .averaging_coefficient_y import averaging_coefficient_y as averaging_coefficient_y_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .reaction_model import reaction_model as reaction_model_cls
class particle_mixture_child(Group):
    """
    'child_object_type' of particle_mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'specific_heat', 'species',
         'vp_equilib', 'thermal_conductivity', 'viscosity', 'dpm_surften',
         'emissivity', 'scattering_factor', 'vaporization_model',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'thermophoretic_co', 'reaction_model']

    name: name_cls = name_cls
    """
    name child of particle_mixture_child.
    """
    chemical_formula: chemical_formula_cls = chemical_formula_cls
    """
    chemical_formula child of particle_mixture_child.
    """
    density: density_cls = density_cls
    """
    density child of particle_mixture_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of particle_mixture_child.
    """
    species: species_cls = species_cls
    """
    species child of particle_mixture_child.
    """
    vp_equilib: vp_equilib_cls = vp_equilib_cls
    """
    vp_equilib child of particle_mixture_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of particle_mixture_child.
    """
    viscosity: viscosity_cls = viscosity_cls
    """
    viscosity child of particle_mixture_child.
    """
    dpm_surften: dpm_surften_cls = dpm_surften_cls
    """
    dpm_surften child of particle_mixture_child.
    """
    emissivity: emissivity_cls = emissivity_cls
    """
    emissivity child of particle_mixture_child.
    """
    scattering_factor: scattering_factor_cls = scattering_factor_cls
    """
    scattering_factor child of particle_mixture_child.
    """
    vaporization_model: vaporization_model_cls = vaporization_model_cls
    """
    vaporization_model child of particle_mixture_child.
    """
    averaging_coefficient_t: averaging_coefficient_t_cls = averaging_coefficient_t_cls
    """
    averaging_coefficient_t child of particle_mixture_child.
    """
    averaging_coefficient_y: averaging_coefficient_y_cls = averaging_coefficient_y_cls
    """
    averaging_coefficient_y child of particle_mixture_child.
    """
    thermophoretic_co: thermophoretic_co_cls = thermophoretic_co_cls
    """
    thermophoretic_co child of particle_mixture_child.
    """
    reaction_model: reaction_model_cls = reaction_model_cls
    """
    reaction_model child of particle_mixture_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .uds_diffusivities_child import uds_diffusivities_child

class uds_diffusivities(NamedObject[uds_diffusivities_child], _NonCreatableNamedObjectMixin[uds_diffusivities_child]):
    """
    'uds_diffusivities' child.
    """

    fluent_name = "uds-diffusivities"

    child_object_type: uds_diffusivities_child = uds_diffusivities_child
    """
    child_object_type of uds_diffusivities.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_2 import enabled as enabled_cls
from .drag_law import drag_law as drag_law_cls
from .lift_law import lift_law as lift_law_cls
class particle_rotation(Group):
    """
    'particle_rotation' child.
    """

    fluent_name = "particle-rotation"

    child_names = \
        ['enabled', 'drag_law', 'lift_law']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of particle_rotation.
    """
    drag_law: drag_law_cls = drag_law_cls
    """
    drag_law child of particle_rotation.
    """
    lift_law: lift_law_cls = lift_law_cls
    """
    lift_law child of particle_rotation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class cone_angle(Real, _HasAllowedValuesMixin):
    """
    Half Angle of Cone Relative to its Axis.
    """

    fluent_name = "cone-angle"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_9 import option as option_cls
from .value import value as value_cls
class struct_damping_beta(Group):
    """
    'struct_damping_beta' child.
    """

    fluent_name = "struct-damping-beta"

    child_names = \
        ['option', 'value']

    option: option_cls = option_cls
    """
    option child of struct_damping_beta.
    """
    value: value_cls = value_cls
    """
    value child of struct_damping_beta.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class poor_mesh_numerics:
    fluent_name = ...
    child_names = ...
    set = ...
    command_names = ...

    def list_properties(self, ):
        """
        List the properties of a definition for automatic poor mesh numerics.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .border_2 import border as border_cls
from .bottom_2 import bottom as bottom_cls
from .clear_2 import clear as clear_cls
from .format_1 import format as format_cls
from .font_size_1 import font_size as font_size_cls
from .left_2 import left as left_cls
from .margin import margin as margin_cls
from .right_3 import right as right_cls
from .top_2 import top as top_cls
from .visible_3 import visible as visible_cls
class scale(Group):
    """
    Enter the color scale window options menu.
    """

    fluent_name = "scale"

    child_names = \
        ['border', 'bottom', 'clear', 'format', 'font_size', 'left', 'margin',
         'right', 'top', 'visible']

    border: border_cls = border_cls
    """
    border child of scale.
    """
    bottom: bottom_cls = bottom_cls
    """
    bottom child of scale.
    """
    clear: clear_cls = clear_cls
    """
    clear child of scale.
    """
    format: format_cls = format_cls
    """
    format child of scale.
    """
    font_size: font_size_cls = font_size_cls
    """
    font_size child of scale.
    """
    left: left_cls = left_cls
    """
    left child of scale.
    """
    margin: margin_cls = margin_cls
    """
    margin child of scale.
    """
    right: right_cls = right_cls
    """
    right child of scale.
    """
    top: top_cls = top_cls
    """
    top child of scale.
    """
    visible: visible_cls = visible_cls
    """
    visible child of scale.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .convergence_reports import convergence_reports as convergence_reports_cls
from .frequency_1 import frequency as frequency_cls
from .condition import condition as condition_cls
from .check_for import check_for as check_for_cls
class convergence_conditions(Group):
    """
    'convergence_conditions' child.
    """

    fluent_name = "convergence-conditions"

    child_names = \
        ['convergence_reports', 'frequency', 'condition', 'check_for']

    convergence_reports: convergence_reports_cls = convergence_reports_cls
    """
    convergence_reports child of convergence_conditions.
    """
    frequency: frequency_cls = frequency_cls
    """
    frequency child of convergence_conditions.
    """
    condition: condition_cls = condition_cls
    """
    condition child of convergence_conditions.
    """
    check_for: check_for_cls = check_for_cls
    """
    check_for child of convergence_conditions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .linearization import linearization as linearization_cls
from .implicit_momentum_coupling import implicit_momentum_coupling as implicit_momentum_coupling_cls
from .implicit_source_term_coupling import implicit_source_term_coupling as implicit_source_term_coupling_cls
from .linear_growth_of_dpm_source_terms import linear_growth_of_dpm_source_terms as linear_growth_of_dpm_source_terms_cls
from .reset_sources_at_timestep import reset_sources_at_timestep as reset_sources_at_timestep_cls
class source_terms(Group):
    """
    'source_terms' child.
    """

    fluent_name = "source-terms"

    child_names = \
        ['linearization', 'implicit_momentum_coupling',
         'implicit_source_term_coupling', 'linear_growth_of_dpm_source_terms',
         'reset_sources_at_timestep']

    linearization: linearization_cls = linearization_cls
    """
    linearization child of source_terms.
    """
    implicit_momentum_coupling: implicit_momentum_coupling_cls = implicit_momentum_coupling_cls
    """
    implicit_momentum_coupling child of source_terms.
    """
    implicit_source_term_coupling: implicit_source_term_coupling_cls = implicit_source_term_coupling_cls
    """
    implicit_source_term_coupling child of source_terms.
    """
    linear_growth_of_dpm_source_terms: linear_growth_of_dpm_source_terms_cls = linear_growth_of_dpm_source_terms_cls
    """
    linear_growth_of_dpm_source_terms child of source_terms.
    """
    reset_sources_at_timestep: reset_sources_at_timestep_cls = reset_sources_at_timestep_cls
    """
    reset_sources_at_timestep child of source_terms.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_8 import enabled as enabled_cls
from .blocking_max_vol_frac import blocking_max_vol_frac as blocking_max_vol_frac_cls
from .drag_scaling_enabled import drag_scaling_enabled as drag_scaling_enabled_cls
from .mom_source_scaling_enabled import mom_source_scaling_enabled as mom_source_scaling_enabled_cls
from .other_source_scaling_enabled import other_source_scaling_enabled as other_source_scaling_enabled_cls
class volume_displacement(Group):
    """
    In many Lagrangian-Eulerian simulations, the volume fraction of the local particle phase may not be small,
    and the blocking effect of the particulate phase on the carrier phase may need to be taken into account.
    To enable the volume displacement effect of particles, select "option = #t".
    """

    fluent_name = "volume-displacement"

    child_names = \
        ['enabled', 'blocking_max_vol_frac', 'drag_scaling_enabled',
         'mom_source_scaling_enabled', 'other_source_scaling_enabled']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of volume_displacement.
    """
    blocking_max_vol_frac: blocking_max_vol_frac_cls = blocking_max_vol_frac_cls
    """
    blocking_max_vol_frac child of volume_displacement.
    """
    drag_scaling_enabled: drag_scaling_enabled_cls = drag_scaling_enabled_cls
    """
    drag_scaling_enabled child of volume_displacement.
    """
    mom_source_scaling_enabled: mom_source_scaling_enabled_cls = mom_source_scaling_enabled_cls
    """
    mom_source_scaling_enabled child of volume_displacement.
    """
    other_source_scaling_enabled: other_source_scaling_enabled_cls = other_source_scaling_enabled_cls
    """
    other_source_scaling_enabled child of volume_displacement.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .reset_defined_derived_quantities import reset_defined_derived_quantities as reset_defined_derived_quantities_cls
from .derived_quantities import derived_quantities as derived_quantities_cls
class data_file_options(Command):
    """
    Set derived quantities to be written in data file.
    
    Parameters
    ----------
        reset_defined_derived_quantities : bool
            'reset_defined_derived_quantities' child.
        derived_quantities : typing.List[str]
            'derived_quantities' child.
    
    """

    fluent_name = "data-file-options"

    argument_names = \
        ['reset_defined_derived_quantities', 'derived_quantities']

    reset_defined_derived_quantities: reset_defined_derived_quantities_cls = reset_defined_derived_quantities_cls
    """
    reset_defined_derived_quantities argument of data_file_options.
    """
    derived_quantities: derived_quantities_cls = derived_quantities_cls
    """
    derived_quantities argument of data_file_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .shell_conduction_child import shell_conduction_child

class shell_conduction(ListObject[shell_conduction_child]):
    """
    'shell_conduction' child.
    """

    fluent_name = "shell-conduction"

    child_object_type: shell_conduction_child = shell_conduction_child
    """
    child_object_type of shell_conduction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .surfaces import surfaces as surfaces_cls
from .techplot_scalars import techplot_scalars as techplot_scalars_cls
class dx(Command):
    """
    Write an IBM Data Explorer format file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surfaces : typing.List[str]
            'surfaces' child.
        techplot_scalars : typing.List[str]
            'techplot_scalars' child.
    
    """

    fluent_name = "dx"

    argument_names = \
        ['name', 'surfaces', 'techplot_scalars']

    name: name_cls = name_cls
    """
    name argument of dx.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces argument of dx.
    """
    techplot_scalars: techplot_scalars_cls = techplot_scalars_cls
    """
    techplot_scalars argument of dx.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fmg_initialize import fmg_initialize as fmg_initialize_cls
from .localized_turb_init import localized_turb_init as localized_turb_init_cls
from .reference_frame_1 import reference_frame as reference_frame_cls
from .fmg_options import fmg_options as fmg_options_cls
from .hybrid_init_options import hybrid_init_options as hybrid_init_options_cls
from .patch import patch as patch_cls
from .set_defaults import set_defaults as set_defaults_cls
from .open_channel_auto_init import open_channel_auto_init as open_channel_auto_init_cls
from .fmg_initialization import fmg_initialization as fmg_initialization_cls
from .initialization_type import initialization_type as initialization_type_cls
from .standard_initialize import standard_initialize as standard_initialize_cls
from .hybrid_initialize import hybrid_initialize as hybrid_initialize_cls
from .initialize import initialize as initialize_cls
from .dpm_reset import dpm_reset as dpm_reset_cls
from .lwf_reset import lwf_reset as lwf_reset_cls
from .init_flow_statistics import init_flow_statistics as init_flow_statistics_cls
from .init_acoustics_options import init_acoustics_options as init_acoustics_options_cls
from .list_defaults import list_defaults as list_defaults_cls
from .init_turb_vel_fluctuations import init_turb_vel_fluctuations as init_turb_vel_fluctuations_cls
from .show_iterations_sampled import show_iterations_sampled as show_iterations_sampled_cls
from .show_time_sampled import show_time_sampled as show_time_sampled_cls
from .levelset_auto_init import levelset_auto_init as levelset_auto_init_cls
class initialization(Group):
    """
    'initialization' child.
    """

    fluent_name = "initialization"

    child_names = \
        ['fmg_initialize', 'localized_turb_init', 'reference_frame',
         'fmg_options', 'hybrid_init_options', 'patch', 'set_defaults',
         'open_channel_auto_init', 'fmg_initialization',
         'initialization_type']

    fmg_initialize: fmg_initialize_cls = fmg_initialize_cls
    """
    fmg_initialize child of initialization.
    """
    localized_turb_init: localized_turb_init_cls = localized_turb_init_cls
    """
    localized_turb_init child of initialization.
    """
    reference_frame: reference_frame_cls = reference_frame_cls
    """
    reference_frame child of initialization.
    """
    fmg_options: fmg_options_cls = fmg_options_cls
    """
    fmg_options child of initialization.
    """
    hybrid_init_options: hybrid_init_options_cls = hybrid_init_options_cls
    """
    hybrid_init_options child of initialization.
    """
    patch: patch_cls = patch_cls
    """
    patch child of initialization.
    """
    set_defaults: set_defaults_cls = set_defaults_cls
    """
    set_defaults child of initialization.
    """
    open_channel_auto_init: open_channel_auto_init_cls = open_channel_auto_init_cls
    """
    open_channel_auto_init child of initialization.
    """
    fmg_initialization: fmg_initialization_cls = fmg_initialization_cls
    """
    fmg_initialization child of initialization.
    """
    initialization_type: initialization_type_cls = initialization_type_cls
    """
    initialization_type child of initialization.
    """
    command_names = \
        ['standard_initialize', 'hybrid_initialize', 'initialize',
         'dpm_reset', 'lwf_reset', 'init_flow_statistics',
         'init_acoustics_options', 'list_defaults',
         'init_turb_vel_fluctuations', 'show_iterations_sampled',
         'show_time_sampled', 'levelset_auto_init']

    standard_initialize: standard_initialize_cls = standard_initialize_cls
    """
    standard_initialize command of initialization.
    """
    hybrid_initialize: hybrid_initialize_cls = hybrid_initialize_cls
    """
    hybrid_initialize command of initialization.
    """
    initialize: initialize_cls = initialize_cls
    """
    initialize command of initialization.
    """
    dpm_reset: dpm_reset_cls = dpm_reset_cls
    """
    dpm_reset command of initialization.
    """
    lwf_reset: lwf_reset_cls = lwf_reset_cls
    """
    lwf_reset command of initialization.
    """
    init_flow_statistics: init_flow_statistics_cls = init_flow_statistics_cls
    """
    init_flow_statistics command of initialization.
    """
    init_acoustics_options: init_acoustics_options_cls = init_acoustics_options_cls
    """
    init_acoustics_options command of initialization.
    """
    list_defaults: list_defaults_cls = list_defaults_cls
    """
    list_defaults command of initialization.
    """
    init_turb_vel_fluctuations: init_turb_vel_fluctuations_cls = init_turb_vel_fluctuations_cls
    """
    init_turb_vel_fluctuations command of initialization.
    """
    show_iterations_sampled: show_iterations_sampled_cls = show_iterations_sampled_cls
    """
    show_iterations_sampled command of initialization.
    """
    show_time_sampled: show_time_sampled_cls = show_time_sampled_cls
    """
    show_time_sampled command of initialization.
    """
    levelset_auto_init: levelset_auto_init_cls = levelset_auto_init_cls
    """
    levelset_auto_init command of initialization.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class multi_layer_refinement:
    fluent_name = ...
    command_names = ...

    def refine_mesh(self, ):
        """
        Refine the mesh for multiple boundary layers.
        """

    def boundary_zones(self, ):
        """
        Specify boundary zones for refinement.
        """

    def layer_count(self, ):
        """
        Specify the layer count for refinement.
        """

    def parameters(self, ):
        """
        Specify parameters for multiple boundary layer refinement.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .design_points import design_points as design_points_cls
class clear_generated_data(Command):
    """
    Clear Generated Data.
    
    Parameters
    ----------
        design_points : typing.List[str]
            'design_points' child.
    
    """

    fluent_name = "clear-generated-data"

    argument_names = \
        ['design_points']

    design_points: design_points_cls = design_points_cls
    """
    design_points argument of clear_generated_data.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class rotating_mesh_flow_predictor(Boolean):
    """
    Improve prediction of flow field at time step n+1 for rotating mesh.
    """

    fluent_name = "rotating-mesh-flow-predictor?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class cgns_export_filetype(String, _HasAllowedValuesMixin):
    """
    Select HDF5 or ADF as file format for CGNS.
    """

    fluent_name = "cgns-export-filetype"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .nodes import nodes as nodes_cls
from .edges_1 import edges as edges_cls
from .faces_1 import faces as faces_cls
from .partitions import partitions as partitions_cls
from .overset_2 import overset as overset_cls
from .gap import gap as gap_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['nodes', 'edges', 'faces', 'partitions', 'overset', 'gap']

    nodes: nodes_cls = nodes_cls
    """
    nodes child of options.
    """
    edges: edges_cls = edges_cls
    """
    edges child of options.
    """
    faces: faces_cls = faces_cls
    """
    faces child of options.
    """
    partitions: partitions_cls = partitions_cls
    """
    partitions child of options.
    """
    overset: overset_cls = overset_cls
    """
    overset child of options.
    """
    gap: gap_cls = gap_cls
    """
    gap child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class airfoil_data_file(String):
    """
    Airfoil data file (cl/cd) at blade section.
    """

    fluent_name = "airfoil-data-file"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .border_1 import border as border_cls
from .bottom_1 import bottom as bottom_cls
from .left_1 import left as left_cls
from .right_2 import right as right_cls
from .top_1 import top as top_cls
from .visible_2 import visible as visible_cls
class main(Group):
    """
    Enter the main view window options menu.
    """

    fluent_name = "main"

    child_names = \
        ['border', 'bottom', 'left', 'right', 'top', 'visible']

    border: border_cls = border_cls
    """
    border child of main.
    """
    bottom: bottom_cls = bottom_cls
    """
    bottom child of main.
    """
    left: left_cls = left_cls
    """
    left child of main.
    """
    right: right_cls = right_cls
    """
    right child of main.
    """
    top: top_cls = top_cls
    """
    top child of main.
    """
    visible: visible_cls = visible_cls
    """
    visible child of main.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .point_surface import point_surface as point_surface_cls
from .line_surface import line_surface as line_surface_cls
from .rake_surface import rake_surface as rake_surface_cls
from .iso_surface import iso_surface as iso_surface_cls
from .plane_surface import plane_surface as plane_surface_cls
class surfaces(Group):
    """
    'surfaces' child.
    """

    fluent_name = "surfaces"

    child_names = \
        ['point_surface', 'line_surface', 'rake_surface', 'iso_surface',
         'plane_surface']

    point_surface: point_surface_cls = point_surface_cls
    """
    point_surface child of surfaces.
    """
    line_surface: line_surface_cls = line_surface_cls
    """
    line_surface child of surfaces.
    """
    rake_surface: rake_surface_cls = rake_surface_cls
    """
    rake_surface child of surfaces.
    """
    iso_surface: iso_surface_cls = iso_surface_cls
    """
    iso_surface child of surfaces.
    """
    plane_surface: plane_surface_cls = plane_surface_cls
    """
    plane_surface child of surfaces.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .add_contact_resistance import add_contact_resistance as add_contact_resistance_cls
from .list_contact_face import list_contact_face as list_contact_face_cls
from .delete_contact_face import delete_contact_face as delete_contact_face_cls
class contact_resistance(Group):
    """
    'contact_resistance' child.
    """

    fluent_name = "contact-resistance"

    command_names = \
        ['add_contact_resistance', 'list_contact_face', 'delete_contact_face']

    add_contact_resistance: add_contact_resistance_cls = add_contact_resistance_cls
    """
    add_contact_resistance command of contact_resistance.
    """
    list_contact_face: list_contact_face_cls = list_contact_face_cls
    """
    list_contact_face command of contact_resistance.
    """
    delete_contact_face: delete_contact_face_cls = delete_contact_face_cls
    """
    delete_contact_face command of contact_resistance.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .type_1 import type as type_cls
from .two_dim_space import two_dim_space as two_dim_space_cls
from .velocity_formulation import velocity_formulation as velocity_formulation_cls
from .time import time as time_cls
class solver(Group):
    """
    'solver' child.
    """

    fluent_name = "solver"

    child_names = \
        ['type', 'two_dim_space', 'velocity_formulation', 'time']

    type: type_cls = type_cls
    """
    type child of solver.
    """
    two_dim_space: two_dim_space_cls = two_dim_space_cls
    """
    two_dim_space child of solver.
    """
    velocity_formulation: velocity_formulation_cls = velocity_formulation_cls
    """
    velocity_formulation child of solver.
    """
    time: time_cls = time_cls
    """
    time child of solver.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class system_coupling:
    fluent_name = ...
    child_names = ...
    htc = ...
    unsteady_statistics = ...
    user_defined_coupling_variables_via_udm = ...
    use_face_or_element_based_data_transfer = ...
    command_names = ...

    def write_scp_file(self, file_name: str):
        """
        Write fluent input scp file for sc.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def connect_parallel(self, schost: str, scport: int, scname: str):
        """
        System coupling connection status.
        
        Parameters
        ----------
            schost : str
                Sc solver host input.
            scport : int
                Sc solver port input.
            scname : str
                Sc solver name input.
        
        """

    def init_and_solve(self, ):
        """
        System-coupling-solve-init-command.
        """

    def solve(self, ):
        """
        System-coupling-solve-command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .session_name import session_name as session_name_cls
from .port import port as port_cls
from .port_span import port_span as port_span_cls
from .job_service_url import job_service_url as job_service_url_cls
class start(Command):
    """
    Start the web server.
    
    Parameters
    ----------
        session_name : str
            Name for the web server.
        port : int
            Listening port for the web server.
        port_span : int
            Number of ports to try starting from given 'port' for the web server.
        job_service_url : str
            Job service URL to register Fluent.
    
    """

    fluent_name = "start"

    argument_names = \
        ['session_name', 'port', 'port_span', 'job_service_url']

    session_name: session_name_cls = session_name_cls
    """
    session_name argument of start.
    """
    port: port_cls = port_cls
    """
    port argument of start.
    """
    port_span: port_span_cls = port_span_cls
    """
    port_span argument of start.
    """
    job_service_url: job_service_url_cls = job_service_url_cls
    """
    job_service_url argument of start.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class report_leidenfrost_temperature(Boolean):
    """
    Enable/disable the reporting of wall film faces above the Leidenfrost point.
    """

    fluent_name = "report-leidenfrost-temperature?"




import pytest

from ansys.fluent.core import examples

import_filename = examples.download_file("mixing_elbow.msh.h5", "pyfluent/mixing_elbow")


@pytest.mark.fluent_version(">=24.2")
def test_meshing_utilities(new_mesh_session):
    meshing_session = new_mesh_session
    meshing_session.tui.file.read_case(import_filename)

    assert meshing_session.meshing_utilities._cell_zones_labels_fdl() == ["elbow-fluid"]

    assert meshing_session.meshing_utilities._cell_zones_str_fdl() == [" 87 "]

    assert meshing_session.meshing_utilities._edge_zones_labels_fdl() == [
        "wall-elbow:wall-inlet:elbow-fluid:feature.28",
        "outlet:wall-elbow:elbow-fluid:feature.27",
        "cold-inlet:wall-elbow:elbow-fluid:feature.26",
        "symmetry:xyplane:wall-elbow:elbow-fluid:feature.25",
        "symmetry:xyplane:wall-inlet:elbow-fluid:feature.24",
        "symmetry:xyplane:outlet:elbow-fluid:feature.23",
        "symmetry:xyplane:cold-inlet:elbow-fluid:feature.22",
        "hot-inlet:wall-inlet:elbow-fluid:feature.21",
        "symmetry:xyplane:hot-inlet:elbow-fluid:feature.20",
    ]

    assert meshing_session.meshing_utilities._edge_zones_str_fdl() == [
        " 28 ",
        " 27 ",
        " 26 ",
        " 25 ",
        " 24 ",
        " 23 ",
        " 22 ",
        " 21 ",
        " 20 ",
    ]

    assert meshing_session.meshing_utilities._face_zones_labels_fdl() == [
        "wall-elbow",
        "wall-inlet",
        "outlet",
        "cold-inlet",
        "hot-inlet",
        "symmetry-xyplane",
    ]

    assert meshing_session.meshing_utilities._face_zones_str_fdl() == [
        " 89 ",
        " 34 ",
        " 33 ",
        " 32 ",
        " 31 ",
        " 30 ",
        " 29 ",
    ]

    assert meshing_session.meshing_utilities._node_zones_labels_fdl() == [
        "boundary-node-163",
        "node-91",
        "boundary-node-19",
    ]

    assert meshing_session.meshing_utilities._node_zones_str_fdl() == [
        " 163 ",
        " 91 ",
        " 19 ",
    ]

    assert meshing_session.meshing_utilities._prism_cell_zones_labels_fdl() is None

    assert meshing_session.meshing_utilities._prism_cell_zones_str_fdl() is None

    assert meshing_session.meshing_utilities._object_names_str_fdl() == ["elbow-fluid"]

    assert meshing_session.meshing_utilities._regions_str_fdl() == [" elbow-fluid "]

    assert meshing_session.meshing_utilities._zone_types_fdl() == [
        "interior",
        "wall",
        "wall",
        "pressure-outlet",
        "velocity-inlet",
        "velocity-inlet",
        "symmetry",
        "boundary-node",
        "node",
        "boundary-node",
        "fluid",
        "boundary-edge",
        "boundary-edge",
        "boundary-edge",
        "boundary-edge",
        "boundary-edge",
        "boundary-edge",
        "boundary-edge",
        "boundary-edge",
        "boundary-edge",
    ]

    assert meshing_session.meshing_utilities.get_labels(object_name="elbow-fluid") == [
        "elbow-fluid",
        "wall-elbow",
        "wall-inlet",
        "outlet",
        "cold-inlet",
        "hot-inlet",
        "symmetry-xyplane",
    ]

    assert meshing_session.meshing_utilities.get_labels(
        object_name="elbow-fluid", filter="*"
    ) == [
        "elbow-fluid",
        "wall-elbow",
        "wall-inlet",
        "outlet",
        "cold-inlet",
        "hot-inlet",
        "symmetry-xyplane",
    ]

    assert meshing_session.meshing_utilities.get_labels(
        object_name="elbow-fluid", label_name_pattern="*"
    ) == [
        "elbow-fluid",
        "wall-elbow",
        "wall-inlet",
        "outlet",
        "cold-inlet",
        "hot-inlet",
        "symmetry-xyplane",
    ]

    assert (
        meshing_session.meshing_utilities.add_labels_on_face_zones(
            face_zone_name_list=["wall-inlet", "wall-elbow"],
            label_name_list=["wall-inlet-1", "wall-elbow-1"],
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_labels_on_face_zones(
        face_zone_name_list=["wall-inlet", "wall-elbow"]
    ) == ["elbow-fluid", "wall-elbow", "wall-inlet-1", "wall-elbow-1", "wall-inlet"]

    assert meshing_session.meshing_utilities.get_face_zone_id_list_with_labels(
        face_zone_name_list=["wall-inlet", "wall-elbow"],
        label_name_list=["wall-inlet-1", "wall-elbow-1"],
    ) == [33, 34, 33, 34]

    assert meshing_session.meshing_utilities.get_face_zone_id_list_with_labels(
        face_zone_id_list=[33, 34],
        label_name_list=["wall-inlet-1", "wall-elbow-1"],
    ) == [33, 34, 33, 34]

    assert meshing_session.meshing_utilities.get_face_zone_id_list_with_labels(
        face_zone_name_pattern="wall*",
        label_name_list=["wall-inlet-1", "wall-elbow-1"],
    ) == [33, 34, 33, 34]

    assert (
        meshing_session.meshing_utilities.add_labels_on_face_zones(
            face_zone_id_list=[30, 31], label_name_list=["hot-inlet-1", "cold-inlet-1"]
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_labels_on_face_zones(
        face_zone_id_list=[30, 31]
    ) == ["elbow-fluid", "cold-inlet", "hot-inlet-1", "cold-inlet-1", "hot-inlet"]

    assert (
        meshing_session.meshing_utilities.add_labels_on_face_zones(
            face_zone_name_pattern="out*", label_name_list=["outlet-1"]
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_labels_on_face_zones(
        face_zone_name_pattern="out*"
    ) == ["elbow-fluid", "outlet", "outlet-1"]

    assert (
        meshing_session.meshing_utilities.remove_labels_on_face_zones(
            face_zone_name_list=["wall-inlet"],
            label_name_list=["wall-inlet-1"],
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.remove_labels_on_face_zones(
            face_zone_id_list=[30],
            label_name_list=["hot-inlet-1"],
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.remove_labels_on_face_zones(
            face_zone_name_pattern="*",
            label_name_list=["wall-elbow-1"],
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.add_labels_on_cell_zones(
            cell_zone_name_list=["elbow-fluid"], label_name_list=["elbow-1"]
        )
        == "*the-non-printing-object*"
    )

    assert meshing_session.meshing_utilities.get_cell_zone_id_list_with_labels(
        cell_zone_name_list=["elbow-fluid"],
        label_name_list=["elbow-1"],
    ) == [87]

    assert meshing_session.meshing_utilities.get_cell_zone_id_list_with_labels(
        cell_zone_id_list=[87],
        label_name_list=["elbow-1"],
    ) == [87]

    assert meshing_session.meshing_utilities.get_cell_zone_id_list_with_labels(
        cell_zone_name_pattern="*",
        label_name_list=["elbow-1"],
    ) == [87]

    assert meshing_session.meshing_utilities.get_labels_on_cell_zones(
        cell_zone_name_list=["elbow-fluid"]
    ) == ["elbow-1"]

    assert (
        meshing_session.meshing_utilities.add_labels_on_cell_zones(
            cell_zone_id_list=[87], label_name_list=["87-1"]
        )
        == "*the-non-printing-object*"
    )

    assert meshing_session.meshing_utilities.get_labels_on_cell_zones(
        cell_zone_id_list=[87]
    ) == ["elbow-1", "87-1"]

    assert (
        meshing_session.meshing_utilities.add_labels_on_cell_zones(
            cell_zone_name_pattern="*", label_name_list=["cell-1"]
        )
        == "*the-non-printing-object*"
    )

    assert meshing_session.meshing_utilities.get_labels_on_cell_zones(
        cell_zone_name_pattern="*"
    ) == ["87-1", "elbow-1", "cell-1"]

    meshing_session.meshing_utilities.remove_labels_on_cell_zones(
        cell_zone_name_list=["elbow-fluid"],
        label_name_list=["elbow-1"],
    )

    assert meshing_session.meshing_utilities.get_labels_on_cell_zones(
        cell_zone_name_pattern="*"
    ) == ["cell-1", "87-1"]

    meshing_session.meshing_utilities.remove_labels_on_cell_zones(
        cell_zone_id_list=[87],
        label_name_list=["87-1"],
    )

    assert meshing_session.meshing_utilities.get_labels_on_cell_zones(
        cell_zone_name_pattern="*"
    ) == ["cell-1"]

    meshing_session.meshing_utilities.remove_labels_on_cell_zones(
        cell_zone_name_pattern="*",
        label_name_list=["cell-1"],
    )

    assert (
        meshing_session.meshing_utilities.get_labels_on_cell_zones(
            cell_zone_name_pattern="*"
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.add_labels_on_edge_zones(
            edge_zone_name_list=[
                "symmetry:xyplane:hot-inlet:elbow-fluid:feature.20",
                "hot-inlet:wall-inlet:elbow-fluid:feature.21",
            ],
            label_name_list=["20-1", "21-1"],
        )
        == "*the-non-printing-object*"
    )

    assert meshing_session.meshing_utilities.get_edge_zone_id_list_with_labels(
        edge_zone_name_list=[
            "symmetry:xyplane:hot-inlet:elbow-fluid:feature.20",
            "hot-inlet:wall-inlet:elbow-fluid:feature.21",
        ],
        label_name_list=["20-1", "21-1"],
    ) == [20, 21, 20, 21]

    assert meshing_session.meshing_utilities.get_edge_zone_id_list_with_labels(
        edge_zone_id_list=[20, 21],
        label_name_list=["20-1", "21-1"],
    ) == [20, 21, 20, 21]

    assert meshing_session.meshing_utilities.get_edge_zone_id_list_with_labels(
        edge_zone_name_pattern="*",
        label_name_list=["20-1", "21-1"],
    ) == [20, 21, 20, 21]

    assert meshing_session.meshing_utilities.get_labels_on_edge_zones(
        edge_zone_name_list=[
            "symmetry:xyplane:hot-inlet:elbow-fluid:feature.20",
            "hot-inlet:wall-inlet:elbow-fluid:feature.21",
        ]
    ) == ["20-1", "21-1"]

    assert (
        meshing_session.meshing_utilities.add_labels_on_edge_zones(
            edge_zone_id_list=[22, 23], label_name_list=["22-1", "23-1"]
        )
        == "*the-non-printing-object*"
    )

    assert meshing_session.meshing_utilities.get_labels_on_edge_zones(
        edge_zone_id_list=[22, 23]
    ) == ["22-1", "23-1"]

    assert (
        meshing_session.meshing_utilities.add_labels_on_edge_zones(
            edge_zone_name_pattern="cold-inlet*", label_name_list=["26-1"]
        )
        == "*the-non-printing-object*"
    )

    assert meshing_session.meshing_utilities.get_labels_on_edge_zones(
        edge_zone_name_pattern="cold-inlet*"
    ) == ["26-1"]

    meshing_session.meshing_utilities.remove_labels_on_edge_zones(
        edge_zone_name_list=["symmetry:xyplane:hot-inlet:elbow-fluid:feature.20"],
        label_name_list=["20-1"],
    )

    meshing_session.meshing_utilities.remove_labels_on_edge_zones(
        edge_zone_id_list=[22],
        label_name_list=["22-1"],
    )

    meshing_session.meshing_utilities.remove_labels_on_edge_zones(
        edge_zone_name_pattern="*",
        label_name_list=["26-1"],
    )

    assert meshing_session.meshing_utilities.convert_zone_name_strings_to_ids(
        zone_name_list=["outlet", "cold-inlet"]
    ) == [32, 31]

    assert meshing_session.meshing_utilities.convert_zone_ids_to_name_strings(
        zone_id_list=[32, 31]
    ) == ["outlet", "cold-inlet"]

    assert meshing_session.meshing_utilities.get_edge_zones(filter="*") == [
        28,
        27,
        26,
        25,
        24,
        23,
        22,
        21,
        20,
    ]

    assert meshing_session.meshing_utilities.get_edge_zones(
        maximum_entity_count=20, only_boundary=False
    ) == [20, 21, 22, 23, 28]

    assert meshing_session.meshing_utilities.get_edge_zones(
        maximum_entity_count=20, only_boundary=True
    ) == [20, 21, 22, 23, 28]

    assert meshing_session.meshing_utilities.get_unreferenced_edge_zones() is None

    assert (
        meshing_session.meshing_utilities.get_unreferenced_edge_zones(filter="*")
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_unreferenced_edge_zones(
            zone_name_pattern="*"
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_face_zones(filter="*") == [
        89,
        34,
        33,
        32,
        31,
        30,
        29,
    ]

    assert meshing_session.meshing_utilities.get_face_zones(prism_control_name="*") == [
        33,
        34,
    ]

    assert (
        meshing_session.meshing_utilities.get_face_zones(
            xyz_coordinates=[1.4, 1.4, 1.4]
        )
        == 34
    )

    assert (
        meshing_session.meshing_utilities.get_face_zones(
            maximum_entity_count=20, only_boundary=True
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_face_zones_by_zone_area(
        maximum_zone_area=100
    ) == [33, 32, 31, 30]

    assert meshing_session.meshing_utilities.get_face_zones_by_zone_area(
        minimum_zone_area=10
    ) == [34, 29]

    assert meshing_session.meshing_utilities.get_face_zones_of_object(
        object_name="elbow-fluid", regions=["elbow-fluid"]
    ) == [34, 33, 32, 31, 30, 29]

    assert meshing_session.meshing_utilities.get_face_zones_of_object(
        object_name="elbow-fluid", labels=["outlet"]
    ) == [32]

    assert (
        meshing_session.meshing_utilities.get_face_zones_of_object(
            object_name="elbow-fluid", region_type="elbow-fluid"
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_face_zones_of_object(
        object_name="elbow-fluid"
    ) == [29, 30, 31, 32, 33, 34]

    assert meshing_session.meshing_utilities.get_face_zones_of_object(
        objects=["elbow-fluid"]
    ) == [29, 30, 31, 32, 33, 34]

    assert meshing_session.meshing_utilities.get_wrapped_face_zones() is None

    assert meshing_session.meshing_utilities.get_unreferenced_face_zones() is None

    assert (
        meshing_session.meshing_utilities.get_unreferenced_face_zones(filter="*")
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_unreferenced_face_zones(
            zone_name_pattern="*"
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_interior_face_zones_for_given_cell_zones(
            cell_zone_id_list=[87]
        )
        == [89]
    )

    assert (
        meshing_session.meshing_utilities.get_interior_face_zones_for_given_cell_zones(
            cell_zone_name_pattern="*"
        )
        == [89]
    )

    assert (
        meshing_session.meshing_utilities.get_interior_face_zones_for_given_cell_zones(
            cell_zone_name_list=["elbow-fluid"]
        )
        == [89]
    )

    assert meshing_session.meshing_utilities.get_node_zones(filter="*") == [163, 91, 19]

    assert meshing_session.meshing_utilities.get_adjacent_zones_by_edge_connectivity(
        zone_id_list=[29, 30, 31, 32, 33]
    ) == [34]
    assert meshing_session.meshing_utilities.get_adjacent_zones_by_edge_connectivity(
        zone_name_list=["outlet", "inlet", "wall", "internal"]
    ) == [34, 29]
    assert (
        meshing_session.meshing_utilities.get_adjacent_zones_by_edge_connectivity(
            zone_name_pattern="*"
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_adjacent_zones_by_node_connectivity(
        zone_id_list=[29, 30, 31, 32, 33]
    ) == [34]

    assert meshing_session.meshing_utilities.get_adjacent_zones_by_node_connectivity(
        zone_name_list=["outlet", "inlet", "wall", "internal"]
    ) == [29, 34]

    assert (
        meshing_session.meshing_utilities.get_adjacent_zones_by_node_connectivity(
            zone_name_pattern="*"
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_cell_zones(filter="*") == [87]

    assert (
        meshing_session.meshing_utilities.get_cell_zones(maximum_entity_count=100)
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_cell_zones(
            xyz_coordinates=[1.4, 1.4, 1.4]
        )
        is False
    )

    assert meshing_session.meshing_utilities.get_unreferenced_cell_zones() is None

    assert (
        meshing_session.meshing_utilities.get_unreferenced_cell_zones(filter="*")
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_unreferenced_cell_zones(
            zone_name_pattern="*"
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_adjacent_cell_zones_for_given_face_zones(
            cell_zone_id_list=[29, 30, 31, 32, 33]
        )
        == [87]
    )

    assert (
        meshing_session.meshing_utilities.get_adjacent_cell_zones_for_given_face_zones(
            cell_zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        == [87]
    )

    assert (
        meshing_session.meshing_utilities.get_adjacent_cell_zones_for_given_face_zones(
            cell_zone_name_pattern="*"
        )
        == [87]
    )

    assert (
        meshing_session.meshing_utilities.get_tet_cell_zones(
            zone_id_list=[29, 30, 31, 32, 33]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_tet_cell_zones(zone_id_list=[87]) is None
    )

    assert (
        meshing_session.meshing_utilities.get_tet_cell_zones(
            zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_tet_cell_zones(zone_name_pattern="*")
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_prism_cell_zones(zone_id_list=[87])
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_prism_cell_zones(
            zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_prism_cell_zones(zone_name_pattern="*")
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_maxsize_cell_zone_by_count(
            zone_id_list=[87]
        )
        == 87
    )

    assert (
        meshing_session.meshing_utilities.get_maxsize_cell_zone_by_count(
            zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_maxsize_cell_zone_by_count(
            zone_name_pattern="*"
        )
        == 87
    )

    assert (
        meshing_session.meshing_utilities.get_maxsize_cell_zone_by_volume(
            zone_id_list=[87]
        )
        == 87
    )

    assert (
        meshing_session.meshing_utilities.get_maxsize_cell_zone_by_volume(
            zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_maxsize_cell_zone_by_volume(
            zone_name_pattern="*"
        )
        == 87
    )

    assert meshing_session.meshing_utilities.get_zones(type_name="velocity-inlet") == [
        30,
        31,
    ]

    assert meshing_session.meshing_utilities.get_zones(group_name="inlet") == [31, 30]

    assert meshing_session.meshing_utilities.get_embedded_baffles() is None

    assert meshing_session.meshing_utilities.get_baffles_for_face_zones(
        face_zone_id_list=[29, 30, 31, 32, 33]
    ) == [33, 32, 31, 30, 29]

    assert (
        meshing_session.meshing_utilities.get_baffles_for_face_zones(
            face_zone_id_list=[87]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_marked_faces_for_given_face_zones(
            face_zone_id_list=[29, 30, 31, 32, 33]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_marked_faces_for_given_face_zones(
            face_zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_marked_faces_for_given_face_zones(
            face_zone_name_pattern="*"
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_multi_faces_for_given_face_zones(
            face_zone_id_list=[29, 30, 31, 32, 33]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_multi_faces_for_given_face_zones(
            face_zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_multi_faces_for_given_face_zones(
            face_zone_name_pattern="*"
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_free_faces_for_given_face_zones(
            face_zone_id_list=[29, 30, 31, 32, 33]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_free_faces_for_given_face_zones(
            face_zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_zones_with_free_faces_for_given_face_zones(
            face_zone_name_pattern="*"
        )
        is None
    )

    assert meshing_session.meshing_utilities.get_all_objects() == ["elbow-fluid"]

    assert meshing_session.meshing_utilities.get_objects(type_name="mesh") == [
        "elbow-fluid"
    ]

    assert meshing_session.meshing_utilities.get_objects(filter="*") == ["elbow-fluid"]

    assert meshing_session.meshing_utilities.get_regions(
        object_name="elbow-fluid", region_name_pattern="*"
    ) == ["elbow-fluid"]

    assert meshing_session.meshing_utilities.get_regions(
        object_name="elbow-fluid", filter="*"
    ) == ["elbow-fluid"]

    assert meshing_session.meshing_utilities.get_regions(object_name="elbow-fluid") == [
        "elbow-fluid"
    ]

    assert meshing_session.meshing_utilities.get_regions_of_face_zones(
        face_zone_id_list=[29, 30, 31, 32, 33]
    ) == ["elbow-fluid"]

    assert meshing_session.meshing_utilities.get_regions_of_face_zones(
        face_zone_name_list=["outlet", "inlet", "wall", "internal"]
    ) == ["elbow-fluid"]

    assert meshing_session.meshing_utilities.get_regions_of_face_zones(
        face_zone_name_pattern="*"
    ) == ["elbow-fluid"]

    assert meshing_session.meshing_utilities.get_region_volume(
        object_name="elbow-fluid", sorting_order="ascending"
    ) == [[152.59942809266, "elbow-fluid"]]

    assert (
        meshing_session.meshing_utilities.get_region_volume(
            object_name="elbow-fluid", region_name="elbow-fluid"
        )
        == 152.59942809266
    )

    assert (
        meshing_session.meshing_utilities.get_pairs_of_overlapping_face_zones(
            face_zone_id_list=[29, 30, 31, 32, 33],
            join_tolerance=0.001,
            absolute_tolerance=True,
            join_angle=45,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_pairs_of_overlapping_face_zones(
            face_zone_name_list=["outlet", "inlet", "wall", "internal"],
            join_tolerance=0.001,
            absolute_tolerance=True,
            join_angle=45,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_pairs_of_overlapping_face_zones(
            face_zone_name_pattern="*",
            join_tolerance=0.001,
            absolute_tolerance=True,
            join_angle=45,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_overlapping_face_zones(
            face_zone_name_pattern="*", area_tolerance=0.01, distance_tolerance=0.01
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.get_minsize_face_zone_by_count(
            zone_id_list=[29, 30, 31, 32, 33]
        )
        == 30
    )

    assert (
        meshing_session.meshing_utilities.get_minsize_face_zone_by_count(
            zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        == 32
    )

    assert (
        meshing_session.meshing_utilities.get_minsize_face_zone_by_count(
            zone_name_pattern="*"
        )
        == 30
    )

    assert (
        meshing_session.meshing_utilities.get_minsize_face_zone_by_area(
            zone_id_list=[29, 30, 31, 32, 33]
        )
        == 30
    )

    assert (
        meshing_session.meshing_utilities.get_minsize_face_zone_by_area(
            zone_name_list=["outlet", "inlet", "wall", "internal"]
        )
        == 32
    )

    assert (
        meshing_session.meshing_utilities.get_minsize_face_zone_by_area(
            zone_name_pattern="*"
        )
        == 30
    )

    assert (
        meshing_session.meshing_utilities.get_adjacent_face_zones_for_given_cell_zones(
            cell_zone_id_list=[87]
        )
        == [29, 30, 31, 32, 33, 34]
    )

    assert (
        meshing_session.meshing_utilities.get_adjacent_face_zones_for_given_cell_zones(
            cell_zone_name_pattern="*"
        )
        == [29, 30, 31, 32, 33, 34]
    )

    assert (
        meshing_session.meshing_utilities.get_adjacent_face_zones_for_given_cell_zones(
            cell_zone_name_list=["elbow-fluid"]
        )
        == [29, 30, 31, 32, 33, 34]
    )

    assert meshing_session.meshing_utilities.get_adjacent_interior_and_boundary_face_zones_for_given_cell_zones(
        cell_zone_id_list=[87]
    ) == [
        29,
        30,
        31,
        32,
        33,
        34,
        89,
    ]

    assert meshing_session.meshing_utilities.get_adjacent_interior_and_boundary_face_zones_for_given_cell_zones(
        cell_zone_name_pattern="*"
    ) == [
        29,
        30,
        31,
        32,
        33,
        34,
        89,
    ]

    assert meshing_session.meshing_utilities.get_adjacent_interior_and_boundary_face_zones_for_given_cell_zones(
        cell_zone_name_list=["elbow-fluid"]
    ) == [
        29,
        30,
        31,
        32,
        33,
        34,
        89,
    ]

    assert (
        meshing_session.meshing_utilities.count_marked_faces(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.count_marked_faces(face_zone_name_pattern="*")
        == 0
    )

    assert (
        meshing_session.meshing_utilities.get_multi_faces_count(
            face_zone_id_list=[30, 31, 32]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.get_multi_faces_count(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.get_multi_faces_count(
            face_zone_name_pattern="*"
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.get_free_faces_count(
            face_zone_id_list=[30, 31, 32]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.get_free_faces_count(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.get_free_faces_count(
            face_zone_name_pattern="*"
        )
        == 0
    )

    assert meshing_session.meshing_utilities.get_edge_size_limits(
        face_zone_id_list=[30, 31, 32]
    ) == [0.02167507486136073, 0.3016698360443115, 0.1515733801031084]

    assert meshing_session.meshing_utilities.get_edge_size_limits(
        face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
    ) == [0.02167507486136073, 0.3016698360443115, 0.1515733801031084]

    assert meshing_session.meshing_utilities.get_edge_size_limits(
        face_zone_name_pattern="*"
    ) == [0.002393084222530175, 0.3613402218724294, 0.1225859010936682]

    assert (
        meshing_session.meshing_utilities.get_cell_zone_shape(cell_zone_id=87)
        == "mixed"
    )

    # Commented due to variation in 10^-16 th place

    # assert meshing_session.meshing_utilities.get_cell_quality_limits(
    #     cell_zone_id_list=[87], measure="Orthogonal Quality"
    # ) == [17822, 0.2453637718621773, 0.9999993965264717, 0.9546058175066768, 0.0, 0]
    #
    # assert meshing_session.meshing_utilities.get_cell_quality_limits(
    #     cell_zone_name_list=["elbow-fluid"], measure="Orthogonal Quality"
    # ) == [17822, 0.2453637718621773, 0.9999993965264717, 0.9546058175066768, 0.0, 0]
    #
    # assert meshing_session.meshing_utilities.get_cell_quality_limits(
    #     cell_zone_name_pattern="*", measure="Orthogonal Quality"
    # ) == [17822, 0.2453637718621773, 0.9999993965264717, 0.9546058175066768, 0.0, 0]
    #
    # assert meshing_session.meshing_utilities.get_face_quality_limits(
    #     face_zone_id_list=[30, 31, 32], measure="Orthogonal Quality"
    # )[1:] == [0.7348979098719086, 0.9999899933604034, 0.9840275981092989, 362]
    #
    # assert meshing_session.meshing_utilities.get_face_quality_limits(
    #     face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
    #     measure="Orthogonal Quality",
    # )[1:] == [0.7348979098719086, 0.9999899933604034, 0.9840275981092989, 362]
    #
    # assert meshing_session.meshing_utilities.get_face_quality_limits(
    #     face_zone_name_pattern="*", measure="Orthogonal Quality"
    # )[1:] == [0.03215596355473505, 1.0, 0.9484456798568045, 91581]

    assert meshing_session.meshing_utilities.get_face_mesh_distribution(
        face_zone_id_list=[30, 31, 32],
        measure="Orthogonal Quality",
        partitions=2,
        range=[0.9, 1],
    ) == [356, [323, 33], [0, 6]]

    assert meshing_session.meshing_utilities.get_face_mesh_distribution(
        face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
        measure="Orthogonal Quality",
        partitions=2,
        range=[0.9, 1],
    ) == [356, [323, 33], [0, 6]]

    assert meshing_session.meshing_utilities.get_face_mesh_distribution(
        face_zone_name_pattern="*",
        measure="Orthogonal Quality",
        partitions=2,
        range=[0.9, 1],
    ) == [83001, [71792, 11209], [0, 8580]]

    assert meshing_session.meshing_utilities.get_cell_mesh_distribution(
        cell_zone_id_list=[87],
        measure="Orthogonal Quality",
        partitions=2,
        range=[0.9, 1],
    ) == [16016, [11740, 4276], [0, 1806]]

    assert meshing_session.meshing_utilities.get_cell_mesh_distribution(
        cell_zone_name_list=["elbow-fluid"],
        measure="Orthogonal Quality",
        partitions=2,
        range=[0.9, 1],
    ) == [16016, [11740, 4276], [0, 1806]]

    assert meshing_session.meshing_utilities.get_cell_mesh_distribution(
        cell_zone_name_pattern="*",
        measure="Orthogonal Quality",
        partitions=2,
        range=[0.9, 1],
    ) == [16016, [11740, 4276], [0, 1806]]

    # Commented due to variation in 10^-13 th place

    # assert (
    #     meshing_session.meshing_utilities.get_cell_zone_volume(cell_zone_id_list=[87])
    #     == 152.5994280926617
    # )
    #
    # assert (
    #     meshing_session.meshing_utilities.get_cell_zone_volume(
    #         cell_zone_name_list=["elbow-fluid"]
    #     )
    #     == 152.5994280926617
    # )
    #
    # assert (
    #     meshing_session.meshing_utilities.get_cell_zone_volume(
    #         cell_zone_name_pattern="*"
    #     )
    #     == 152.5994280926617
    # )

    # Commented due to variation in 10^-15 th place

    # assert (
    #     meshing_session.meshing_utilities.get_face_zone_area(
    #         face_zone_id_list=[30, 31, 32]
    #     )
    #     == 12.429615960819163
    # )
    #
    # assert (
    #     meshing_session.meshing_utilities.get_face_zone_area(
    #         face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
    #     )
    #     == 12.429615960819163
    # )

    # Commented due to variation in 10^-15 th place

    # assert (
    #     meshing_session.meshing_utilities.get_face_zone_area(face_zone_name_pattern="*")
    #     == 2282.142530887569
    # )

    assert (
        meshing_session.meshing_utilities.get_face_zone_count(
            face_zone_id_list=[30, 31, 32]
        )
        == 362
    )

    assert (
        meshing_session.meshing_utilities.get_face_zone_count(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
        )
        == 362
    )

    assert (
        meshing_session.meshing_utilities.get_face_zone_count(
            face_zone_name_pattern="*"
        )
        == 91581
    )

    assert (
        meshing_session.meshing_utilities.get_cell_zone_count(cell_zone_id_list=[87])
        == 17822
    )

    assert (
        meshing_session.meshing_utilities.get_cell_zone_count(
            cell_zone_name_list=["elbow-fluid"]
        )
        == 17822
    )

    assert (
        meshing_session.meshing_utilities.get_cell_zone_count(
            cell_zone_name_pattern="*"
        )
        == 17822
    )

    assert meshing_session.meshing_utilities.get_zone_type(zone_id=87) == "fluid"

    assert (
        meshing_session.meshing_utilities.get_zone_type(zone_name="elbow-fluid")
        == "fluid"
    )

    assert (
        meshing_session.meshing_utilities.get_face_zone_node_count(face_zone_id=32)
        == 246
    )

    assert (
        meshing_session.meshing_utilities.get_face_zone_node_count(
            face_zone_name="outlet"
        )
        == 246
    )

    assert (
        meshing_session.meshing_utilities.mark_free_faces(
            face_zone_id_list=[30, 31, 32]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_free_faces(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_free_faces(face_zone_name_pattern="*")
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_multi_faces(
            face_zone_id_list=[30, 31, 32], fringe_length=5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_multi_faces(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"], fringe_length=5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_multi_faces(
            face_zone_name_pattern="*", fringe_length=5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_self_intersecting_faces(
            face_zone_id_list=[87], mark_folded=True
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_self_intersecting_faces(
            face_zone_name_list=["elbow-fluid"], mark_folded=True
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_self_intersecting_faces(
            face_zone_name_pattern="elbow*", mark_folded=True
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_duplicate_faces(
            face_zone_id_list=[30, 31, 32]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_duplicate_faces(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_duplicate_faces(
            face_zone_name_pattern="*"
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_invalid_normals(
            face_zone_id_list=[30, 31, 32]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_invalid_normals(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"]
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_invalid_normals(
            face_zone_name_pattern="*"
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_island_faces(
            face_zone_id_list=[30, 31, 32], island_face_count=5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_island_faces(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
            island_face_count=5,
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_island_faces(
            face_zone_name_pattern="cold*", island_face_count=5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_spikes(
            face_zone_id_list=[30, 31, 32], spike_angle=40.5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_spikes(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"], spike_angle=40.5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_spikes(
            face_zone_name_pattern="*", spike_angle=40.5
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_steps(
            face_zone_id_list=[30, 31, 32], step_angle=40.5, step_width=3.3
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_steps(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
            step_angle=40.5,
            step_width=3.3,
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_steps(
            face_zone_name_pattern="*", step_angle=40.5, step_width=3.3
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_sliver_faces(
            face_zone_id_list=[30, 31, 32], max_height=2, skew_limit=0.2
        )
        == 2
    )

    assert (
        meshing_session.meshing_utilities.mark_sliver_faces(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
            max_height=2,
            skew_limit=0.2,
        )
        == 2
    )

    assert (
        meshing_session.meshing_utilities.mark_sliver_faces(
            face_zone_name_pattern="*", max_height=2.2, skew_limit=0.5
        )
        == 3453
    )

    assert (
        meshing_session.meshing_utilities.mark_bad_quality_faces(
            face_zone_id_list=[30, 31, 32], quality_limit=0.5, number_of_rings=2
        )
        == 362
    )

    assert (
        meshing_session.meshing_utilities.mark_bad_quality_faces(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
            quality_limit=0.5,
            number_of_rings=2,
        )
        == 362
    )

    # assert meshing_session.meshing_utilities.mark_bad_quality_faces(face_zone_name_pattern="*", quality_limit=0.5,
    #                                                        number_of_rings=2) == 4799

    assert (
        meshing_session.meshing_utilities.mark_face_strips_by_height_and_quality(
            face_zone_id_list=[30, 31, 32],
            strip_type=2,
            strip_height=2,
            quality_measure="Size Change",
            quality_limit=0.5,
            feature_angle=40,
        )
        == -125
    )

    assert (
        meshing_session.meshing_utilities.mark_face_strips_by_height_and_quality(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
            strip_type=2,
            strip_height=2,
            quality_measure="Size Change",
            quality_limit=0.5,
            feature_angle=40.5,
        )
        == -125
    )

    assert (
        meshing_session.meshing_utilities.mark_face_strips_by_height_and_quality(
            face_zone_name_pattern="cold*",
            strip_type=1,
            strip_height=2,
            quality_measure="Size Change",
            quality_limit=0.5,
            feature_angle=40.5,
        )
        == -51
    )

    assert (
        meshing_session.meshing_utilities.mark_faces_deviating_from_size_field(
            face_zone_id_list=[87],
            min_size_factor=0.5,
            max_size_factor=1.1,
            size_factor_type_to_compare="geodesic",
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_faces_deviating_from_size_field(
            face_zone_name_list=["elbow-fluid"],
            min_size_factor=0.5,
            max_size_factor=1.1,
            size_factor_type_to_compare="geodesic",
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_faces_deviating_from_size_field(
            face_zone_name_pattern="elbow*",
            min_size_factor=0.5,
            max_size_factor=1.1,
            size_factor_type_to_compare="geodesic",
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_faces_using_node_degree(
            face_zone_id_list=[87], node_degree_threshold=2
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_faces_using_node_degree(
            face_zone_name_list=["elbow-fluid"], node_degree_threshold=2
        )
        == 0
    )

    assert (
        meshing_session.meshing_utilities.mark_faces_using_node_degree(
            face_zone_name_pattern="elbow*", node_degree_threshold=2
        )
        == 0
    )

    # Commented due to variation in 10^-16 th place

    # assert meshing_session.meshing_utilities.get_average_bounding_box_center(
    #     face_zone_id_list=[30, 31, 32]
    # ) == [1.1482939720153809, -2.2965879440307617, 0.7345014897547645]
    #
    # assert meshing_session.meshing_utilities.get_bounding_box_of_zone_list(
    #     zone_id_list=[26]
    # ) == [
    #     [-7.874015808105469, -7.874015808105469, 0.0],
    #     [-7.874015808105469, -3.937007904052734, 1.963911771774292],
    # ]

    assert (
        meshing_session.meshing_utilities.unpreserve_cell_zones(cell_zone_id_list=[87])
        is False
    )

    assert (
        meshing_session.meshing_utilities.unpreserve_cell_zones(
            cell_zone_name_list=["elbow-fluid"]
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.unpreserve_cell_zones(
            cell_zone_name_pattern="*"
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.create_boi_and_size_functions_from_refinement_regions(
            region_type="hexcore", boi_prefix_string="wall", create_size_function=True
        )
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.scale_face_zones_around_pivot(
            face_zone_id_list=[30, 31, 32],
            scale=[1.1, 1.2, 1.3],
            pivot=[1.1482939720153809, -2.2965879440307617, 0.7345014897547645],
            use_bbox_center=True,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.scale_face_zones_around_pivot(
            face_zone_name_list=["cold-inlet", "hot-inlet", "outlet"],
            scale=[1.1, 1.2, 1.3],
            pivot=[1.1482939720153809, -2.2965879440307617, 0.7345014897547645],
            use_bbox_center=True,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.scale_face_zones_around_pivot(
            face_zone_name_pattern="*",
            scale=[1.1, 1.2, 1.3],
            pivot=[1.1482939720153809, -2.2965879440307617, 0.7345014897547645],
            use_bbox_center=True,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.scale_cell_zones_around_pivot(
            cell_zone_id_list=[87],
            scale=[1.1, 1.2, 1.3],
            pivot=[1.1482939720153809, -2.2965879440307617, 0.7345014897547645],
            use_bbox_center=True,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.scale_cell_zones_around_pivot(
            cell_zone_name_list=["elbow-fluid"],
            scale=[1.1, 1.2, 1.3],
            pivot=[1.1482939720153809, -2.2965879440307617, 0.7345014897547645],
            use_bbox_center=True,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.scale_cell_zones_around_pivot(
            cell_zone_name_pattern="*",
            scale=[1.1, 1.2, 1.3],
            pivot=[1.1482939720153809, -2.2965879440307617, 0.7345014897547645],
            use_bbox_center=True,
        )
        is None
    )

    assert meshing_session.meshing_utilities.dump_face_zone_orientation_in_region(
        file_name="facezonetest.txt"
    ) == [
        [29, "elbow-fluid"],
        [30, "elbow-fluid"],
        [31, "elbow-fluid"],
        [32, "elbow-fluid"],
        [33, "elbow-fluid"],
        [34, "elbow-fluid"],
    ]

    assert (
        meshing_session.meshing_utilities.set_quality_measure(measure="Aspect Ratio")
        is None
    )

    assert (
        meshing_session.meshing_utilities.set_object_cell_zone_type(
            object_name="elbow-fluid", cell_zone_type="mixed"
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.set_number_of_parallel_compute_threads(
            nthreads=2
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.rename_face_zone(
            zone_id=32, new_name="outlet-32"
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.rename_face_zone(
            zone_name="outlet-32", new_name="outlet"
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.rename_edge_zone(
            zone_id=20, new_name="symmetry:xyplane:hot-inlet:elbow-fluid:feature.20-new"
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.rename_face_zone(
            zone_name="symmetry:xyplane:hot-inlet:elbow-fluid:feature.20-new",
            new_name="symmetry:xyplane:hot-inlet:elbow-fluid:feature.20",
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.remove_id_suffix_from_face_zones()
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.clean_face_zone_names()
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.remove_ids_from_zone_names(
            zone_id_list=[30, 31, 32]
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.renumber_zone_ids(
            zone_id_list=[30, 31, 32], start_number=1
        )
        == "*the-non-printing-object*"
    )

    assert meshing_session.meshing_utilities.rename_object(
        old_object_name="elbow-fluid", new_object_name="elbow-fluid-1"
    ) == [
        "elbow-fluid-1",
        "solid",
        10,
        [29, 33, 34, 1, 2, 3],
        [20, 21, 22, 23, 24, 25, 26, 27, 28],
        "mesh",
        [
            [
                "elbow-fluid",
                "fluid",
                [3.981021240569742, 7.614496699403261, 0.02968953016527287],
                [3, 2, 1, 34, 33, 29],
                [[87], None],
            ]
        ],
        [
            ["outlet-1", "fluid", 1, [3], None, "geom", False, None],
            ["hot-inlet-1", "fluid", 1, [2], None, "geom", False, None],
            ["cold-inlet-1", "fluid", 1, [2, 1], None, "geom", False, None],
            ["wall-inlet-1", "fluid", 1, [34], None, "geom", False, None],
            [
                "elbow-fluid",
                "solid",
                10,
                [3, 2, 1, 34, 33, 29],
                None,
                "geom",
                None,
                None,
                None,
                "body",
            ],
            [
                "wall-elbow",
                "solid",
                10,
                [34],
                None,
                "geom",
                None,
                None,
                None,
                "facelabel",
            ],
            [
                "wall-inlet",
                "solid",
                10,
                [33],
                None,
                "geom",
                None,
                None,
                None,
                "facelabel",
            ],
            ["outlet", "solid", 10, [3], None, "geom", None, None, None, "facelabel"],
            [
                "cold-inlet",
                "solid",
                10,
                [2],
                None,
                "geom",
                None,
                None,
                None,
                "facelabel",
            ],
            [
                "hot-inlet",
                "solid",
                10,
                [1],
                None,
                "geom",
                None,
                None,
                None,
                "facelabel",
            ],
            [
                "symmetry-xyplane",
                "solid",
                10,
                [29],
                None,
                "geom",
                None,
                None,
                None,
                "facelabel",
            ],
        ],
        [[87], None],
        [None],
        None,
    ]

    assert (
        meshing_session.meshing_utilities.replace_object_suffix(
            object_name_list=["elbow-fluid"], separator="-", new_suffix="fluid-new"
        )
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.rename_face_zone_label(
            object_name="elbow-fluid-1",
            old_label_name="outlet",
            new_label_name="outlet-new",
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.replace_label_suffix(
            object_name_list=["elbow-fluid-1"], separator="-", new_suffix="fluid-new"
        )
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.copy_face_zone_labels(
            from_face_zone_id=33, to_face_zone_id=34
        )
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.merge_face_zones(
            face_zone_id_list=[30, 31, 32]
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.merge_face_zones(
            face_zone_name_pattern="wall*"
        )
        == 34
    )

    assert (
        meshing_session.meshing_utilities.merge_face_zones_of_type(
            face_zone_type="velocity-inlet", face_zone_name_pattern="*"
        )
        == 1
    )

    assert (
        meshing_session.meshing_utilities.merge_face_zones_with_same_prefix(
            prefix="elbow"
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.merge_cell_zones(cell_zone_id_list=[87])
        is False
    )

    assert (
        meshing_session.meshing_utilities.merge_cell_zones(
            cell_zone_name_list=["elbow-fluid"]
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.merge_cell_zones(cell_zone_name_pattern="*")
        is False
    )

    assert (
        meshing_session.meshing_utilities.merge_cell_zones_with_same_prefix(
            prefix="elbow"
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.merge_cell_zones_with_same_suffix(
            suffix="fluid"
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.separate_face_zones_by_cell_neighbor(
            face_zone_id_list=[30, 31, 32]
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.separate_face_zones_by_cell_neighbor(
            face_zone_name_list=["wall-inlet", "wallfluid-new"]
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.separate_face_zones_by_cell_neighbor(
            face_zone_name_pattern="*"
        )
        is True
    )

    assert (
        meshing_session.meshing_utilities.refine_marked_faces_in_zones(
            face_zone_id_list=[30, 31, 32]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.refine_marked_faces_in_zones(
            face_zone_name_list=["wall-inlet", "wallfluid-new"]
        )
        is None
    )

    assert meshing_session.meshing_utilities.refine_marked_faces_in_zones(
        face_zone_name_pattern="*"
    ) == [0, 0, 0, 0, 0]

    assert (
        meshing_session.meshing_utilities.fill_holes_in_face_zone_list(
            face_zone_id_list=[30, 31, 32], max_hole_edges=2
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.fill_holes_in_face_zone_list(
            face_zone_name_list=["wall-inlet", "wallfluid-new"], max_hole_edges=2
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.fill_holes_in_face_zone_list(
            face_zone_name_pattern="wall*", max_hole_edges=2
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.project_zone_on_plane(
            zone_id=87, plane=[[1, 0, 0], [0, 1, 0], [0, 0, 1]]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.delete_all_sub_domains()
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.delete_marked_faces_in_zones(
            face_zone_id_list=[30, 31, 32]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.delete_marked_faces_in_zones(
            face_zone_name_list=["wall-inlet", "wallfluid-new"]
        )
        is None
    )

    assert meshing_session.meshing_utilities.delete_marked_faces_in_zones(
        face_zone_name_pattern="*"
    ) == [0, 0, 0, 0, 3446]

    assert (
        meshing_session.meshing_utilities.delete_empty_face_zones(
            face_zone_id_list=[30, 31, 32]
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.delete_empty_face_zones(
            face_zone_name_list=["wall-inlet", "wallfluid-new"]
        )
        is None
    )

    assert meshing_session.meshing_utilities.delete_empty_face_zones(
        face_zone_name_pattern="*"
    ) == [29, 1, 3, 34, 89]

    assert meshing_session.meshing_utilities.delete_empty_cell_zones(
        cell_zone_id_list=[87]
    ) == [87]

    assert meshing_session.meshing_utilities.delete_empty_cell_zones(
        cell_zone_name_list=["elbow.87"]
    ) == [87]

    assert meshing_session.meshing_utilities.delete_empty_cell_zones(
        cell_zone_name_pattern="*"
    ) == [87]

    assert meshing_session.meshing_utilities.delete_empty_edge_zones(
        edge_zone_id_list=[20, 25, 26]
    ) == [26, 25, 20]

    assert meshing_session.meshing_utilities.delete_empty_edge_zones(
        edge_zone_name_list=[
            "symmetry:xyplane:hot-inlet:elbow-fluid:feature.20",
            "hot-inlet:wall-inlet:elbow-fluid:feature.21",
        ]
    ) == [21]

    assert meshing_session.meshing_utilities.delete_empty_edge_zones(
        edge_zone_name_pattern="*"
    ) == [28, 27, 26, 25, 24, 23, 22, 21, 20]

    assert meshing_session.meshing_utilities.delete_empty_zones(
        zone_id_list=[20, 32, 87]
    ) == [20, 87]

    assert meshing_session.meshing_utilities.delete_empty_zones(
        zone_name_list=["hotfluid-new", "elbow.87"]
    ) == [87]

    assert meshing_session.meshing_utilities.delete_empty_zones(
        zone_name_pattern="*"
    ) == [169, 163, 19, 28, 27, 26, 25, 24, 23, 22, 21, 20, 29, 1, 3, 34, 89, 87]

    assert meshing_session.meshing_utilities.boundary_zone_exists(zone_id=31) is False

    assert (
        meshing_session.meshing_utilities.boundary_zone_exists(zone_name="wall-inlet")
        is False
    )

    assert meshing_session.meshing_utilities.interior_zone_exists(zone_id=31) is False

    assert (
        meshing_session.meshing_utilities.interior_zone_exists(zone_name="wall-inlet")
        is False
    )

    assert meshing_session.meshing_utilities.cell_zone_exists(zone_id=87) is True

    assert (
        meshing_session.meshing_utilities.cell_zone_exists(zone_name="elbow.87") is True
    )

    assert meshing_session.meshing_utilities.mesh_exists() is True

    assert (
        meshing_session.meshing_utilities.replace_face_zone_suffix(
            face_zone_id_list=[30, 31, 32],
            separator="-suffix-",
            replace_with="-with-",
            merge=False,
        )
        is False
    )

    assert (
        meshing_session.meshing_utilities.replace_face_zone_suffix(
            face_zone_name_list=["cold-inlet", "hot-inlet"],
            separator="-suffix-",
            replace_with="-with-",
            merge=False,
        )
        is False
    )

    assert meshing_session.meshing_utilities.replace_cell_zone_suffix(
        cell_zone_id_list=[87], old_suffix="fluid", new_suffix="fluid-new", merge=True
    ) == [False]

    assert (
        meshing_session.meshing_utilities.replace_cell_zone_suffix(
            cell_zone_name_list=["elbow-fluid-new"],
            old_suffix="fluid",
            new_suffix="fluid-new",
            merge=True,
        )
        is None
    )

    assert (
        meshing_session.meshing_utilities.replace_edge_zone_suffix(
            edge_zone_id_list=[20],
            old_suffix="fluid",
            new_suffix="fluid-new",
            merge=True,
        )
        == "*the-non-printing-object*"
    )

    assert (
        meshing_session.meshing_utilities.replace_edge_zone_suffix(
            edge_zone_name_list=["hot-inlet:wall-inlet:elbow-fluid:feature.21"],
            old_suffix="fluid",
            new_suffix="fluid-new",
            merge=True,
        )
        == "*the-non-printing-object*"
    )



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .normal import normal as normal_cls
from .distance_from_origin import distance_from_origin as distance_from_origin_cls
from .display_3 import display as display_cls
class plane_slice_child(Group):
    """
    'child_object_type' of plane_slice.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'normal', 'distance_from_origin']

    name: name_cls = name_cls
    """
    name child of plane_slice_child.
    """
    normal: normal_cls = normal_cls
    """
    normal child of plane_slice_child.
    """
    distance_from_origin: distance_from_origin_cls = distance_from_origin_cls
    """
    distance_from_origin child of plane_slice_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of plane_slice_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class by_type:
    fluent_name = ...
    child_names = ...
    only_list_case_boundaries = ...
    use_inherent_material_color = ...
    type_name = ...
    command_names = ...

    def reset(self, ):
        """
        To reset colors and/or materials to the defaults.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .playback import playback as playback_cls
class animations(Group):
    """
    'animations' child.
    """

    fluent_name = "animations"

    child_names = \
        ['playback']

    playback: playback_cls = playback_cls
    """
    playback child of animations.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .type_4 import type as type_cls
from .boundaries import boundaries as boundaries_cls
from .locations import locations as locations_cls
class volumes_child(Group):
    """
    'child_object_type' of volumes.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'type', 'boundaries', 'locations']

    name: name_cls = name_cls
    """
    name child of volumes_child.
    """
    type: type_cls = type_cls
    """
    type child of volumes_child.
    """
    boundaries: boundaries_cls = boundaries_cls
    """
    boundaries child of volumes_child.
    """
    locations: locations_cls = locations_cls
    """
    locations child of volumes_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_turb_damping import enable_turb_damping as enable_turb_damping_cls
from .turb_damping_factor import turb_damping_factor as turb_damping_factor_cls
class turbulence_damping(Group):
    """
    'turbulence_damping' child.
    """

    fluent_name = "turbulence-damping"

    child_names = \
        ['enable_turb_damping', 'turb_damping_factor']

    enable_turb_damping: enable_turb_damping_cls = enable_turb_damping_cls
    """
    enable_turb_damping child of turbulence_damping.
    """
    turb_damping_factor: turb_damping_factor_cls = turb_damping_factor_cls
    """
    turb_damping_factor child of turbulence_damping.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class contour_child:
    fluent_name = ...
    child_names = ...
    name = ...
    field = ...
    filled = ...
    boundary_values = ...
    contour_lines = ...
    node_values = ...
    surfaces_list = ...
    range_option = ...
    coloring = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    physics = ...
    geometry = ...
    surfaces = ...
    deformation = ...
    deformation_scale = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def update_min_max(self, ):
        """
        'update_min_max' command.
        """




"""A module for controlling the writing of Fluent Python journals."""


class Journal:
    """Control the writing of Fluent Python journals."""

    def __init__(self, scheme_eval):
        """__init__ method of Journal class."""
        self.scheme_eval = scheme_eval

    def start(self, file_name: str):
        """Start writing a Fluent Python journal at the specified file_name."""
        self.scheme_eval.exec([f'(api-start-python-journal "{file_name}")'])

    def stop(self):
        """Stop writing the Fluent Python journal."""
        self.scheme_eval.exec([f"(api-stop-python-journal)"])



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class histogram:
    fluent_name = ...
    child_names = ...
    cell_function = ...
    auto_range = ...
    minimum = ...
    maximum = ...
    num_divisions = ...
    all_zones = ...
    zones = ...
    axes = ...
    curves = ...
    command_names = ...

    def print(self, ):
        """
        Print a histogram of a scalar quantity.
        """

    def plot(self, ):
        """
        Plot a histogram of a scalar quantity.
        """

    def write(self, file_name: str):
        """
        Write a histogram of a scalar quantity to a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .command_name import command_name as command_name_cls
class disable(Command):
    """
    Disable an execute-command.
    
    Parameters
    ----------
        command_name : str
            'command_name' child.
    
    """

    fluent_name = "disable"

    argument_names = \
        ['command_name']

    command_name: command_name_cls = command_name_cls
    """
    command_name argument of disable.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class expert:
    fluent_name = ...
    command_names = ...

    def enforce_flux_scaling(self, enable_scale_all: bool, disable_scale_all: bool, interface_name: str, scale: bool):
        """
        Enforce flux scaling ON/OFF at the turbo interfaces.
        
        Parameters
        ----------
            enable_scale_all : bool
                Scale scaling of all the interfaces...
            disable_scale_all : bool
                Disable scaling of all the interfaces...
            interface_name : str
                'interface_name' child.
            scale : bool
                Enable flux scaling at mixing plane interface.
        
        """

    def print_settings(self, ):
        """
        List the flux scale settings at the turbo interfaces.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class enable_auto_creation_of_scp_file(Boolean):
    """
    Enable/disable automatic creation of scp file during case write.
    """

    fluent_name = "enable-auto-creation-of-scp-file?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .methods import methods as methods_cls
from .controls_1 import controls as controls_cls
from .report_definitions import report_definitions as report_definitions_cls
from .monitor_1 import monitor as monitor_cls
from .cell_registers import cell_registers as cell_registers_cls
from .initialization import initialization as initialization_cls
from .calculation_activity import calculation_activity as calculation_activity_cls
from .run_calculation import run_calculation as run_calculation_cls
class solution(Group):
    """
    'solution' child.
    """

    fluent_name = "solution"

    child_names = \
        ['methods', 'controls', 'report_definitions', 'monitor',
         'cell_registers', 'initialization', 'calculation_activity',
         'run_calculation']

    methods: methods_cls = methods_cls
    """
    methods child of solution.
    """
    controls: controls_cls = controls_cls
    """
    controls child of solution.
    """
    report_definitions: report_definitions_cls = report_definitions_cls
    """
    report_definitions child of solution.
    """
    monitor: monitor_cls = monitor_cls
    """
    monitor child of solution.
    """
    cell_registers: cell_registers_cls = cell_registers_cls
    """
    cell_registers child of solution.
    """
    initialization: initialization_cls = initialization_cls
    """
    initialization child of solution.
    """
    calculation_activity: calculation_activity_cls = calculation_activity_cls
    """
    calculation_activity child of solution.
    """
    run_calculation: run_calculation_cls = run_calculation_cls
    """
    run_calculation child of solution.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties_1 import list_properties as list_properties_cls
from .child_object_type_child_1 import child_object_type_child

class direction_vector(ListObject[child_object_type_child]):
    """
    'direction_vector' child.
    """

    fluent_name = "direction-vector"

    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of direction_vector.
    """
    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of direction_vector.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .project_filename import project_filename as project_filename_cls
class new(Command):
    """
    Create New Project.
    
    Parameters
    ----------
        project_filename : str
            'project_filename' child.
    
    """

    fluent_name = "new"

    argument_names = \
        ['project_filename']

    project_filename: project_filename_cls = project_filename_cls
    """
    project_filename argument of new.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class cell_to_limiting(String, _HasAllowedValuesMixin):
    """
    Cell to face limiting ([no] for cell to cell limiting) .
    """

    fluent_name = "cell-to-limiting"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .impedance_2_child import impedance_2_child

class impedance_2(ListObject[impedance_2_child]):
    """
    'impedance_2' child.
    """

    fluent_name = "impedance-2"

    child_object_type: impedance_2_child = impedance_2_child
    """
    child_object_type of impedance_2.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class cell_zone_conditions:
    fluent_name = ...
    child_names = ...
    fluid = ...
    solid = ...
    command_names = ...

    def copy(self, from_: str, to: List[str], verbosity: bool):
        """
        'copy' command.
        
        Parameters
        ----------
            from_ : str
                'from' child.
            to : typing.List[str]
                'to' child.
            verbosity : bool
                'verbosity' child.
        
        """

    def set_zone_type(self, zone_list: List[str], new_type: str):
        """
        'set_zone_type' command.
        
        Parameters
        ----------
            zone_list : typing.List[str]
                Enter zone name list.
            new_type : str
                'new_type' child.
        
        """

    def activate_cell_zone(self, cell_zone_list: List[str]):
        """
        Activate a cell thread.
        
        Parameters
        ----------
            cell_zone_list : typing.List[str]
                'cell_zone_list' child.
        
        """

    def mrf_to_sliding_mesh(self, cell_zone_name: str):
        """
        Change motion specification from MRF to moving mesh.
        
        Parameters
        ----------
            cell_zone_name : str
                Enter a cell zone name.
        
        """

    def convert_all_solid_mrf_to_solid_motion(self, ):
        """
        Change all solid zones motion specification from MRF to solid motion.
        """

    def copy_mrf_to_mesh_motion(self, zone_name: str, overwrite: bool):
        """
        Copy motion variable values for origin, axis and velocities from Frame Motion to Mesh Motion.
        
        Parameters
        ----------
            zone_name : str
                Enter a zone name.
            overwrite : bool
                'overwrite' child.
        
        """

    def copy_mesh_to_mrf_motion(self, zone_name: str, overwrite: bool):
        """
        Copy motion variable values for origin, axis and velocities from Mesh Motion to Frame Motion.
        
        Parameters
        ----------
            zone_name : str
                Enter a zone name.
            overwrite : bool
                'overwrite' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .disk_child import disk_child

class disk(NamedObject[disk_child], _CreatableNamedObjectMixin[disk_child]):
    """
    Main menu to define a rotor disk:
    
     - delete : delete a vbm disk
     - edit   : edit a vbm disk
     - new    : create a new vbm disk
     - rename : rename a vbm disk.
    
    """

    fluent_name = "disk"

    child_object_type: disk_child = disk_child
    """
    child_object_type of disk.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .udm_index import udm_index as udm_index_cls
from .zone_names_6 import zone_names as zone_names_cls
from .extensive import extensive as extensive_cls
from .input import input as input_cls
from .output_1 import output as output_cls
from .output_variable_name import output_variable_name as output_variable_name_cls
from .input_variable_name import input_variable_name as input_variable_name_cls
class user_defined_coupling_variables_via_udm_child(Group):
    """
    'child_object_type' of user_defined_coupling_variables_via_udm.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['udm_index', 'zone_names', 'extensive', 'input', 'output',
         'output_variable_name', 'input_variable_name']

    udm_index: udm_index_cls = udm_index_cls
    """
    udm_index child of user_defined_coupling_variables_via_udm_child.
    """
    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names child of user_defined_coupling_variables_via_udm_child.
    """
    extensive: extensive_cls = extensive_cls
    """
    extensive child of user_defined_coupling_variables_via_udm_child.
    """
    input: input_cls = input_cls
    """
    input child of user_defined_coupling_variables_via_udm_child.
    """
    output: output_cls = output_cls
    """
    output child of user_defined_coupling_variables_via_udm_child.
    """
    output_variable_name: output_variable_name_cls = output_variable_name_cls
    """
    output_variable_name child of user_defined_coupling_variables_via_udm_child.
    """
    input_variable_name: input_variable_name_cls = input_variable_name_cls
    """
    input_variable_name child of user_defined_coupling_variables_via_udm_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .field import field as field_cls
from .filled import filled as filled_cls
from .boundary_values import boundary_values as boundary_values_cls
from .contour_lines import contour_lines as contour_lines_cls
from .node_values import node_values as node_values_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .range_option import range_option as range_option_cls
from .coloring import coloring as coloring_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics import physics as physics_cls
from .geometry_3 import geometry as geometry_cls
from .surfaces import surfaces as surfaces_cls
from .deformation import deformation as deformation_cls
from .deformation_scale import deformation_scale as deformation_scale_cls
from .display_2 import display as display_cls
class contour_child(Group):
    """
    'child_object_type' of contour.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'filled', 'boundary_values', 'contour_lines',
         'node_values', 'surfaces_list', 'range_option', 'coloring',
         'color_map', 'draw_mesh', 'mesh_object', 'display_state_name',
         'physics', 'geometry', 'surfaces', 'deformation',
         'deformation_scale']

    name: name_cls = name_cls
    """
    name child of contour_child.
    """
    field: field_cls = field_cls
    """
    field child of contour_child.
    """
    filled: filled_cls = filled_cls
    """
    filled child of contour_child.
    """
    boundary_values: boundary_values_cls = boundary_values_cls
    """
    boundary_values child of contour_child.
    """
    contour_lines: contour_lines_cls = contour_lines_cls
    """
    contour_lines child of contour_child.
    """
    node_values: node_values_cls = node_values_cls
    """
    node_values child of contour_child.
    """
    surfaces_list: surfaces_list_cls = surfaces_list_cls
    """
    surfaces_list child of contour_child.
    """
    range_option: range_option_cls = range_option_cls
    """
    range_option child of contour_child.
    """
    coloring: coloring_cls = coloring_cls
    """
    coloring child of contour_child.
    """
    color_map: color_map_cls = color_map_cls
    """
    color_map child of contour_child.
    """
    draw_mesh: draw_mesh_cls = draw_mesh_cls
    """
    draw_mesh child of contour_child.
    """
    mesh_object: mesh_object_cls = mesh_object_cls
    """
    mesh_object child of contour_child.
    """
    display_state_name: display_state_name_cls = display_state_name_cls
    """
    display_state_name child of contour_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of contour_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of contour_child.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of contour_child.
    """
    deformation: deformation_cls = deformation_cls
    """
    deformation child of contour_child.
    """
    deformation_scale: deformation_scale_cls = deformation_scale_cls
    """
    deformation_scale child of contour_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of contour_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class pv_coupling_controls(Boolean):
    """
    Enable/disable pressure-velocity coupling method change for solver stability and accuracy.
    """

    fluent_name = "pv-coupling-controls?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class always_use_face_centroid_with_periodics(Boolean):
    """
    Enable/disable using quad face centroids when creating subtets if the case contains periodic boundaries.
    """

    fluent_name = "always-use-face-centroid-with-periodics?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .print_to_console import print_to_console as print_to_console_cls
from .write_to_file_2 import write_to_file as write_to_file_cls
from .report_definitions_child import report_definitions_child

class report_definitions(NamedObject[report_definitions_child], _CreatableNamedObjectMixin[report_definitions_child]):
    """
    'report_definitions' child.
    """

    fluent_name = "report-definitions"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy',
         'print_to_console', 'write_to_file']

    delete: delete_cls = delete_cls
    """
    delete command of report_definitions.
    """
    list: list_cls = list_cls
    """
    list command of report_definitions.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of report_definitions.
    """
    make_a_copy: make_a_copy_cls = make_a_copy_cls
    """
    make_a_copy command of report_definitions.
    """
    print_to_console: print_to_console_cls = print_to_console_cls
    """
    print_to_console command of report_definitions.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file command of report_definitions.
    """
    child_object_type: report_definitions_child = report_definitions_child
    """
    child_object_type of report_definitions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .start_frame import start_frame as start_frame_cls
from .end_frame import end_frame as end_frame_cls
from .increment import increment as increment_cls
class set_custom_frames(Group):
    """
    Set custom frames start, end, skip frames for video export.
    """

    fluent_name = "set-custom-frames"

    child_names = \
        ['start_frame', 'end_frame', 'increment']

    start_frame: start_frame_cls = start_frame_cls
    """
    start_frame child of set_custom_frames.
    """
    end_frame: end_frame_cls = end_frame_cls
    """
    end_frame child of set_custom_frames.
    """
    increment: increment_cls = increment_cls
    """
    increment child of set_custom_frames.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .heat_exchanger import heat_exchanger as heat_exchanger_cls
from .fluid_zone import fluid_zone as fluid_zone_cls
from .boundary_zone_1 import boundary_zone as boundary_zone_cls
from .report_type import report_type as report_type_cls
from .write_to_file_1 import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_file import append_file as append_file_cls
class mass_flow_rate(Command):
    """
    Print mass flow rate.
    
    Parameters
    ----------
        heat_exchanger : str
            'heat_exchanger' child.
        fluid_zone : str
            'fluid_zone' child.
        boundary_zone : str
            Enter face zone name.
        report_type : str
            'report_type' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_file : bool
            'append_file' child.
    
    """

    fluent_name = "mass-flow-rate"

    argument_names = \
        ['heat_exchanger', 'fluid_zone', 'boundary_zone', 'report_type',
         'write_to_file', 'file_name', 'append_file']

    heat_exchanger: heat_exchanger_cls = heat_exchanger_cls
    """
    heat_exchanger argument of mass_flow_rate.
    """
    fluid_zone: fluid_zone_cls = fluid_zone_cls
    """
    fluid_zone argument of mass_flow_rate.
    """
    boundary_zone: boundary_zone_cls = boundary_zone_cls
    """
    boundary_zone argument of mass_flow_rate.
    """
    report_type: report_type_cls = report_type_cls
    """
    report_type argument of mass_flow_rate.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file argument of mass_flow_rate.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of mass_flow_rate.
    """
    append_file: append_file_cls = append_file_cls
    """
    append_file argument of mass_flow_rate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .from_ import from_ as from__cls
from .to_1 import to as to_cls
from .verbosity_3 import verbosity as verbosity_cls
class copy(Command):
    """
    'copy' command.
    
    Parameters
    ----------
        from_ : str
            'from' child.
        to : typing.List[str]
            'to' child.
        verbosity : bool
            'verbosity' child.
    
    """

    fluent_name = "copy"

    argument_names = \
        ['from_', 'to', 'verbosity']

    from_: from__cls = from__cls
    """
    from_ argument of copy.
    """
    to: to_cls = to_cls
    """
    to argument of copy.
    """
    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity argument of copy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .frequency_type import frequency_type as frequency_type_cls
from .save_frequency import save_frequency as save_frequency_cls
class save_data_file_every(Group):
    """
    Set the auto save frequency type to either time-step or crank-angle and set the corresponding frequency.
    """

    fluent_name = "save-data-file-every"

    child_names = \
        ['frequency_type', 'save_frequency']

    frequency_type: frequency_type_cls = frequency_type_cls
    """
    frequency_type child of save_data_file_every.
    """
    save_frequency: save_frequency_cls = save_frequency_cls
    """
    save_frequency child of save_data_file_every.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .repair_1 import repair as repair_cls
from .disable_repair import disable_repair as disable_repair_cls
class repair_face_handedness(Command):
    """
    Correct face handedness at left handed faces if possible.
    
    Parameters
    ----------
        repair : bool
            'repair' child.
        disable_repair : bool
            'disable_repair' child.
    
    """

    fluent_name = "repair-face-handedness"

    argument_names = \
        ['repair', 'disable_repair']

    repair: repair_cls = repair_cls
    """
    repair argument of repair_face_handedness.
    """
    disable_repair: disable_repair_cls = disable_repair_cls
    """
    disable_repair argument of repair_face_handedness.
    """
